@@ -7,7 +7,11 @@ use warnings;
 use DBI;
 use Carp 'croak';
 use Exporter::NoWork;
+use Rose::DB::Object::Loader;
+
+use DB;
 use autodie;
+
 sub db_handle {
 	my $db_file = shift
 		or croak "db_handle() requires a database name";
@@ -132,4 +136,48 @@ SQL
 
 }
 
+sub build_mysql_db {
+	my $dbh = shift;
+
+	my $sql_media_type = <<"SQL";
+	CREATE TABLE IF NOT EXISTS media_types (
+    id INT NOT NULL AUTO_INCREMENT,
+    media_type VARCHAR(10) NOT NULL,
+    PRIMARY KEY (id)
+);
+SQL
+
+	$dbh->do($sql_media_type);
+
+	my $sql_license = <<"SQL";
+CREATE TABLE IF NOT EXISTS licenses (
+    id INT NOT NULL AUTO_INCREMENT,
+    name VARCHAR(255) NOT NULL,
+    allows_commercial TINYINT(1) NOT NULL,
+    PRIMARY KEY (id)
+);
+SQL
+
+	$dbh->do($sql_license);
+
+	my $sql_media = <<"SQL";
+CREATE TABLE IF NOT EXISTS media (
+    id INT NOT NULL AUTO_INCREMENT,
+    name VARCHAR(255) NOT NULL,
+    location VARCHAR(255) NOT NULL,
+    source VARCHAR(511) NOT NULL,
+    attribution VARCHAR(255) NOT NULL,
+    media_type_id INT NOT NULL,
+    license_id INT NOT NULL,
+    PRIMARY KEY (id),
+    FOREIGN KEY (media_type_id) REFERENCES media_types(id),
+    FOREIGN KEY (license_id) REFERENCES licenses(id)
+);
+SQL
+
+	$dbh->do($sql_media);
+
+	return 1;
+}
+
 1;
